@@ -3,6 +3,8 @@ if (requireNamespace("testthat", quietly = TRUE)) {
   library(testthat)
   library(mlr3)
   library(mcboost)
+  library(mlr3proba)
+  library(mlr3pipelines)
 
   test_check("mcboost")
-}
\ No newline at end of file
+}
